# TARTRL

---
[![Twitter](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Ftwitter.com%2FTARTRL_Lab)](https://twitter.com/TARTRL_Lab)

[![Documentation Status](https://readthedocs.org/projects/tartrl-docs/badge/?version=latest)](https://tartrl-docs.readthedocs.io/zh/latest/?badge=latest)

![GitHub Org's stars](https://img.shields.io/github/stars/TARTRL)
[![GitHub stars](https://img.shields.io/github/stars/TARTRL/TARTRL)](https://github.com/opendilab/TARTRL/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/network)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/TARTRL/TARTRL)
[![GitHub issues](https://img.shields.io/github/issues/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/issues)
[![GitHub pulls](https://img.shields.io/github/issues-pr/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/pulls)
[![Contributors](https://img.shields.io/github/contributors/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/graphs/contributors)
[![GitHub license](https://img.shields.io/github/license/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/blob/master/LICENSE)

## 欢迎来到TARTRL

[中文文档](https://tartrl-docs.readthedocs.io/zh/latest/) | [Documentation](https://tartrl-docs.readthedocs.io/en/latest/)

TARTRL是一个开源的强化学习框架。

## 目录

- [欢迎来到TARTRL](#欢迎来到tartrl)
- [目录](#目录)
- [安装](#安装)
- [快速上手](#快速上手)
- [支持者](#支持者)
  - [&#8627; Stargazers](#-stargazers)
  - [&#8627; Forkers](#-forkers)
- [Citing TARTRL](#citing-tartrl)
- [License](#license)
- [致谢](#致谢)

## 安装

```bash
pip install tartrl
```

## 快速上手

可以通过命令行快速训练`CartPole`环境:
```bash
tartrl --mode train --env CartPole-v1
```

## 支持者

### &#8627; Stargazers

[![Stargazers repo roster for @TARTRL/TARTRL](https://reporoster.com/stars/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/stargazers)

### &#8627; Forkers

[![Forkers repo roster for @TARTRL/TARTRL](https://reporoster.com/forks/TARTRL/TARTRL)](https://github.com/TARTRL/TARTRL/network/members)

## Citing TARTRL

如果我们的工作对你有帮助，欢迎引用我们的论文:
```latex
@misc{tartrl2023,
    title={TARTRL},
    author={TARTRL Contributors},
    publisher = {GitHub},
    howpublished = {\url{https://github.com/TARTRL/TARTRL}},
    year={2023},
}
```

## License
TARTRL under the Apache 2.0 license.

## 致谢
